<?php

function leia_la_settings_page() {
    // Verificar se o formulário foi enviado
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        // Verificar nonce por segurança
        if (isset($_POST['leia_la_nonce']) && wp_verify_nonce($_POST['leia_la_nonce'], 'leia_la_save_settings')) {
            // Atualizar o token
            update_option('leia_la_token', sanitize_text_field($_POST['leia_la_token']));
            
            // Atualizar os post types selecionados
            $selected_post_types = isset($_POST['leia_la_post_types']) ? $_POST['leia_la_post_types'] : [];
            update_option('leia_la_post_types', $selected_post_types);
			
			// Atualizar a opção de ativar/desativar o texto ao copiar
			$enable_copy_text = isset($_POST['leia_la_enable_copy_text']) ? 1 : 0;
			update_option('leia_la_enable_copy_text', $enable_copy_text);

            // Mensagem de feedback
            echo '<div class="updated"><p>Configurações salvas com sucesso!</p></div>';
        } else {
            // Mensagem de erro
            echo '<div class="error"><p>Erro ao salvar as configurações.</p></div>';
        }

        // Testar a API
        if (isset($_POST['test_api'])) {
            $api = new LeiaLaAPI(get_option('leia_la_token'));
            $current_time = date('YmdHis');  // Obtém a data e hora atual no formato 'AnoMêsDiaHoraMinutoSegundo'
            $test_url = 'https://leiala.com.br/teste?data=' . $current_time;  // Anexa a data e hora à URL de teste
            $result = $api->create_short_url($test_url);

            if ($result) {
                echo '<div class="updated"><p>API está funcionando corretamente! URL curta gerada: <a href="'.$result.'" target="_blank">'.$result.'</a>. <a href="https://leia.la/dashboard/links" target="_blank">Verifique no painel Leia.la</a>.</p></div>';
            } else {
                echo '<div class="error"><p>Erro ao testar a API.</p></div>';
            }
        }
    }

    // Obter o token atual
    $token = get_option('leia_la_token', '');
	$selected_post_types = get_option('leia_la_post_types', ['post', 'page']);
	$post_types = get_post_types(['public' => true], 'objects');

    ?>
    <div class="wrap">
        <h2>Configurações Leia.lá</h2>
        <form method="post" action="">
            <?php wp_nonce_field('leia_la_save_settings', 'leia_la_nonce'); ?>

            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Token da API Leia.lá</th>
                    <td>
                        <input type="password" id="leia_la_token_field" name="leia_la_token" value="<?php echo esc_attr($token); ?>" class="regular-text" />
                        <label>
                            <input type="checkbox" id="leia_la_toggle_visibility" value="1">
                            Mostrar Token
                        </label>
                        <p class="description">
                            O token é usado para autenticar seu site com a API Leia.lá e permitir a criação de URLs curtas. Se você não tem um token, pode <a href="https://leia.la/account-settings" target="_blank">obter um aqui</a>.
                        </p>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Post Types</th>
                    <td>
                        <?php 
                        foreach ($post_types as $post_type) {
                            $checked = in_array($post_type->name, $selected_post_types) ? 'checked' : '';
                            echo '<label>';
                            echo '<input type="checkbox" name="leia_la_post_types[]" value="' . esc_attr($post_type->name) . '" ' . $checked . '> ';
                            echo $post_type->labels->name;
                            echo '</label><br>';
                        }
                        ?>
                        <p class="description">
                            Selecione os post types para os quais você deseja gerar URLs curtas.
                        </p>
                    </td>
                </tr>
				
				
                <tr valign="top">
                    <th scope="row">URL ao Copiar Texto</th>
                    <td>
                        <?php echo '<input type="checkbox" name="leia_la_enable_copy_text" value="1"' . checked(1, get_option('leia_la_enable_copy_text', 1), false) . ' /> Incluir link curto no texto copiado'; ?>
                        <p class="description">
							Quando um visitante copiar um trecho do site, o link curto será anexado automaticamente.
                        </p>
                    </td>
                </tr>
				
				
            </table>
			
			


            <p class="submit">
                <?php submit_button('Salvar Configurações', 'primary', 'submit', false); ?>
                <input type="submit" name="test_api" id="test_api" class="button button-secondary" value="Testar API">
            </p>
        </form>
		
		
		<div class="post-box">
			<h2>Conteúdo com URL's curtas</h2>
			<?php
			$total_posts = wp_count_posts('post')->publish;
			wp_localize_script('leia-la-admin-js', 'leiaLaData', ['totalPosts' => $total_posts]);
			$short_url_posts = new WP_Query([
				'post_type' => 'post',
				'post_status' => 'publish',
				'meta_key' => '_leia_la_short_url',
				'meta_compare' => 'EXISTS',
				'nopaging' => true
			]);

			echo '<p>Total de Posts: ' . $total_posts . '</p>';
			echo '<p>Posts com URL curta: ' . $short_url_posts->post_count . '</p>';


			?>
		
		</div>
		
    </div>

    <script>
        document.getElementById('leia_la_toggle_visibility').addEventListener('change', function() {
            const tokenField = document.getElementById('leia_la_token_field');
            if (this.checked) {
                tokenField.type = 'text';
            } else {
                tokenField.type = 'password';
            }
        });
    </script>


    <?php
}

// Adicionar a página de configuração ao menu de Configurações
function leia_la_add_settings_page() {
    add_options_page('Configurações Leia.lá', 'Leia.lá', 'manage_options', 'leia-la-settings', 'leia_la_settings_page');
}
add_action('admin_menu', 'leia_la_add_settings_page');