<?php
/**
 * Plugin Name: Leia.lá
 * Description: Encurte URLs com Leia.la, rastreie de forma profissional e gere estatísticas detalhadas.
 * Version: 1.01
 * Author: <a href="https://leiala.com.br" target="_blank">Leia.la</a>
 */

// Evitar acesso direto ao arquivo
defined('ABSPATH') or die('Acesso direto proibido!');

// Carregar arquivos necessários
require_once(plugin_dir_path(__FILE__) . 'includes/class-leia-la-api.php');
require_once(plugin_dir_path(__FILE__) . 'includes/class-leia-la-admin.php');
require_once(plugin_dir_path(__FILE__) . 'includes/functions.php');
require_once(plugin_dir_path(__FILE__) . 'admin/settings-page.php');

// Informar para configurar token
function leia_la_admin_notices() {
    // Verificar se o token está configurado
    $token = get_option('leia_la_token', '');
    
    if (empty($token)) {
        echo '<div class="notice notice-warning is-dismissible">';
        echo '<p>';
        echo 'Para usar o plugin Leia.lá, você precisa configurar seu token. ';
        echo '<a href="' . admin_url('options-general.php?page=leia-la-settings') . '">Clique aqui para configurar.</a>';
        echo '</p>';
        echo '</div>';
    }
}
add_action('admin_notices', 'leia_la_admin_notices');

// Adicionar os links "Configurações" e "Suporte" abaixo do nome do plugin
function leia_la_plugin_action_links($links) {
    $settings_link = '<a href="' . admin_url('options-general.php?page=leia-la-settings') . '">Configurações</a>'; // Assumindo que sua página de configuração é 'leia-la-settings'
    $support_link = '<a href="https://leiala.com.br/contact" target="_blank">Suporte</a>';

    // Inserir os novos links no início do array
    array_unshift($links, $settings_link, $support_link);

    return $links;
}
$plugin_file_name = plugin_basename(__FILE__);
add_filter("plugin_action_links_{$plugin_file_name}", 'leia_la_plugin_action_links');

// Adicionar os demais links abaixo da descrição do plugin
function leia_la_plugin_row_meta($links, $file) {
    // Verifique se estamos vendo o plugin correto
    if ($file == plugin_basename(__FILE__)) {
        $video_tutorials_link = '<a href="https://leiala.com.br/tutorials" target="_blank">Tutoriais em vídeo</a>';
        $visit_plugin_site_link = '<a href="http://leiala.com.br/wordpress" target="_blank">Visitar o site do plugin</a>';
        $changelog_link = '<a href="http://leiala.com.br/changelog/plugin-wordpress" target="_blank">Histórico de atualizações</a>';
        
        $links = array_merge($links, [$video_tutorials_link, $visit_plugin_site_link, $changelog_link]);
    }
    return $links;
}
add_filter('plugin_row_meta', 'leia_la_plugin_row_meta', 10, 2);


// Inicializar classes e funcionalidades ao ativar o plugin
function leia_la_activate_plugin() {
    if (!get_option('leia_la_token')) {
        add_option('leia_la_token', '');
    }
    if (!get_option('leia_la_post_types')) {
        add_option('leia_la_post_types', ['post', 'page']);  // Por padrão, 'post' e 'page' estão selecionados.
    }
}
register_activation_hook(__FILE__, 'leia_la_activate_plugin');


// Hook para gerar URL curta ao publicar ou atualizar post
function leia_la_generate_short_url($post_id) {
	$token = get_option('leia_la_token', '');
	if (empty($token)) {
		return;
	}

    // Se é revisão, retornar
    if (wp_is_post_revision($post_id)) {
        return;
    }

    $post_status = get_post_status($post_id);
    
    // Somente processar se o post estiver publicado
    if ($post_status != 'publish') {
        return;
    }

    $post_url = get_permalink($post_id);
    $previous_url = get_post_meta($post_id, '_leia_la_long_url', true);
    $short_url = get_post_meta($post_id, '_leia_la_short_url', true);

    $selected_post_types = get_option('leia_la_post_types', ['post']);
    if (!in_array(get_post_type($post_id), $selected_post_types)) {
        return;
    }

    // Se não tivermos uma URL curta ou a URL do post mudou
    if (!$short_url || ($previous_url && $previous_url != $post_url)) {
        $api = new LeiaLaAPI(get_option('leia_la_token'));
        $new_short_url = $api->create_short_url($post_url);
        
        if ($new_short_url) {
            // Atualize a URL curta e a URL longa nas meta informações do post
            update_post_meta($post_id, '_leia_la_short_url', $new_short_url);
            update_post_meta($post_id, '_leia_la_long_url', $post_url);
        }
    }
}
add_action('save_post', 'leia_la_generate_short_url');

// Adicionar coluna na lista de posts para exibir a URL curta
function leia_la_add_column($columns) {
    $token = get_option('leia_la_token', '');

    // Se o token não estiver configurado, retorne as colunas sem modificações
    if (empty($token)) {
        return $columns;
    }

    // Seu código original para adicionar a coluna...
    $icon_url = plugins_url('assets/img/icon-on.svg', __FILE__);
    $columns['leia_la_url'] = '<img src="' . esc_url($icon_url) . '" alt="Leia.lá" title="Leia.lá" style="display: inline;" /> Leia.lá';
    return $columns;
}

function leia_la_display_short_url($column, $post_id) {
    if ($column == 'leia_la_url') {
        $short_url = get_post_meta($post_id, '_leia_la_short_url', true);
        if ($short_url) {
            $icon_url = plugins_url('assets/img/icon-on.svg', __FILE__);
            echo '<a href="#" data-url="' . esc_url($short_url) . '" data-tooltip="Copiar URL curta" class="leia-la-icon" onclick="copyToClipboard(event);"><img src="' . esc_url($icon_url) . '" alt="Copiar URL curta" /></a>';
        } else {
			$icon_url = plugins_url('assets/img/icon-off.svg', __FILE__);
			echo '<a href="#" class="generate-leia-la-url leia-la-icon" data-post-id="' . $post_id . '" data-tooltip="Gerar URL curta"><img src="' . esc_url($icon_url) . '" alt="Gerar URL curta" /></a>';
        }
    }
}

$selected_post_types = get_option('leia_la_post_types', ['post', 'page']);
foreach ($selected_post_types as $post_type) {
    add_filter("manage_{$post_type}_posts_columns", 'leia_la_add_column');
    add_action("manage_{$post_type}_posts_custom_column", 'leia_la_display_short_url', 10, 2);
}

// Enfileirar estilos e scripts
function leia_la_enqueue_admin_assets() {
    // Enfileira o CSS
    wp_enqueue_style('leia-la-admin-css', plugins_url('assets/css/admin.css', __FILE__));

    // Enfileira o JS
    wp_enqueue_script('leia-la-admin-js', plugins_url('assets/js/admin.js', __FILE__));
}
add_action('admin_enqueue_scripts', 'leia_la_enqueue_admin_assets');

// Filtro para adicionar dropdown de seleção
function leia_la_filter_dropdown() {
    global $typenow, $selected_post_types;  // Adicione $selected_post_types aqui
    if (in_array($typenow, $selected_post_types)) {
        $selected = isset($_GET['filter_by_short_url']) ? $_GET['filter_by_short_url'] : '';
        echo '<select name="filter_by_short_url" id="filter_by_short_url">';
        echo '<option value="">' . __('Filtrar por URL curta', 'leia_la') . '</option>';
        echo '<option value="has_short_url"' . selected('has_short_url', $selected, false) . '>' . __('Tem URL curta', 'leia_la') . '</option>';
        echo '<option value="no_short_url"' . selected('no_short_url', $selected, false) . '>' . __('Não tem URL curta', 'leia_la') . '</option>';
        echo '</select>';
    }
}


foreach ($selected_post_types as $post_type) {
    add_action("restrict_manage_posts_{$post_type}", 'leia_la_filter_dropdown');
}

// Filtro para processar seleção do dropdown
function leia_la_filter_posts($query) {
    global $pagenow;
    if (is_admin() && $pagenow == 'edit.php' && isset($_GET['filter_by_short_url']) && $_GET['filter_by_short_url'] != '') {
        if ($_GET['filter_by_short_url'] == 'has_short_url') {
            $query->query_vars['meta_key'] = '_leia_la_short_url';
            $query->query_vars['meta_compare'] = 'EXISTS';
        } elseif ($_GET['filter_by_short_url'] == 'no_short_url') {
            $query->query_vars['meta_key'] = '_leia_la_short_url';
            $query->query_vars['meta_compare'] = 'NOT EXISTS';
        }
    }
}
add_filter('parse_query', 'leia_la_filter_posts');

// Tornar a coluna "Ordenável"
function leia_la_orderable_column($columns) {
    // Remove a coluna Leia.lá se ela já existir
    unset($columns['leia_la_url']);
    
    // Adiciona a coluna Leia.lá ao final
    $leia_la_column = array(
        'leia_la_url' => '<img src="' . esc_url($icon_url) . '" alt="Leia.lá" title="Leia.lá" style="display: inline;" /> Leia.lá'
    );
    $columns += $leia_la_column;
    
    return $columns;
}
foreach ($selected_post_types as $post_type) {
    add_filter("manage_edit-{$post_type}_sortable_columns", 'leia_la_orderable_column');
}

// Definir a lógica de ordenação para a coluna
function leia_la_order_by_custom_column($query) {
    if (!is_admin()) {
        return;
    }

    $orderby = $query->get('orderby');

    if ('leia_la_url' == $orderby) {
        $query->set('meta_key', '_leia_la_short_url');
        $query->set('orderby', 'meta_value');
    }
}
add_action('pre_get_posts', 'leia_la_order_by_custom_column');

function generate_leia_la_url_ajax() {
	$token = get_option('leia_la_token', '');
	if (empty($token)) {
		wp_send_json_error(['message' => 'Token não configurado']);
	}

    $post_id = intval($_POST['post_id']);

    $post_url = get_permalink($post_id);
    $api = new LeiaLaAPI(get_option('leia_la_token'));
    $short_url = $api->create_short_url($post_url);
    
    if ($short_url) {
        update_post_meta($post_id, '_leia_la_short_url', $short_url);
        update_post_meta($post_id, '_leia_la_long_url', $post_url);

        wp_send_json_success(['short_url' => $short_url]);
    } else {
        wp_send_json_error();
    }
}
add_action('wp_ajax_generate_leia_la_url', 'generate_leia_la_url_ajax');


function leia_la_row_actions($actions, $post) {
    // Verifique se o tipo de post está na lista de tipos de postagem selecionados
    $selected_post_types = get_option('leia_la_post_types', ['post', 'page']);
    if (in_array($post->post_type, $selected_post_types)) {
        $short_url = get_post_meta($post->ID, '_leia_la_short_url', true);
        if ($short_url) {
            // Se a URL curta já existe, adicione a ação para copiar
            $actions['copy_short_url'] = '<a href="#" data-url="' . esc_url($short_url) . '" onclick="copyToClipboard(event);">Copiar URL curta</a>';
        } else {
            // Se a URL curta não existir, adicione a ação para gerar
            $actions['generate_short_url'] = '<a href="#" class="generate-leia-la-url" data-post-id="' . $post->ID . '">Gerar URL curta</a>';
        }
    }
    return $actions;
}

// Adicione a função leia_la_row_actions aos filtros de ação da linha para cada tipo de postagem
foreach ($selected_post_types as $post_type) {
    add_filter("{$post_type}_row_actions", 'leia_la_row_actions', 10, 2);
}
						 
							

// Adicione o Leia.lá quando usuário copiar um conteúdo
function leia_la_enqueue_custom_copy_text() {
    if (get_option('leia_la_enable_copy_text')) {
        wp_enqueue_script('leia-la-custom-copy-text', plugins_url('assets/js/custom-copy-text.js', __FILE__), array(), '1.0.0', true);
        
        // Localize a URL curta, se existir, ou a URL do post
        global $post;
        $short_url = get_post_meta($post->ID, '_leia_la_short_url', true);
        $url_to_share = $short_url ? $short_url : get_permalink($post->ID);
        
        wp_localize_script('leia-la-custom-copy-text', 'leiaLaCopyData', ['url' => $url_to_share]);			
												 
    }
}
add_action('wp_enqueue_scripts', 'leia_la_enqueue_custom_copy_text');



?>